durationtools.yield_all_positive_integer_pairs
==============================================

.. autofunction:: abjad.tools.durationtools.yield_all_positive_integer_pairs.yield_all_positive_integer_pairs
